#!/usr/bin/python
# -*- coding: utf-8 -*-

from __future__ import print_function
from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer

from storage import Storage
import json
import re

class BatcaveHttpRequestHandler(BaseHTTPRequestHandler):
	storage = Storage()

	def do_GET(self):
		url = self.path

		if url == '/':
			self.respond_index()
			return

		m = re.match(r'^/node/([a-f0-9]{12})\.json$', url)
		if m != None:
			self.respond_node(m.group(1))
			return

		self.send_error(404, 'The URL \'{0}\' was not found here.'.format(url))

	def respond_index(self):
		self.send_response(200)
		self.send_header('Content-Type', 'text/html; charset=utf-8')
		self.end_headers()

		self.wfile.write('<!DOCTYPE html><html><head><title>BATCAVE</title></head>\n')
		self.wfile.write('<body>\n')
		self.wfile.write('<H1 title="Batman/Alfred Transmission Collection, Aggregation & Value Engine">BATCAVE</H1>\n')

		self.wfile.write('<p>Dies ist ein interner Hintergrund-Dienst. Er wird nur von anderen Diensten\n')
		self.wfile.write('angesprochen und sollte aus einer Mehrzahl von Gr&uuml;nden nicht &ouml;ffentlich\n')
		self.wfile.write('zug&auml;nglich sein.</p>\n')

		self.wfile.write('<H2>Status</H2>\n')
		self.wfile.write('Daten: <span id="datacount" class="value">')
		self.wfile.write(len(self.storage.data))
		self.wfile.write('</span>\n')

		self.wfile.write('<H2>API</H2>\n')
		self.wfile.write('<p>Grundsätzlich ist das Antwort-Format JSON und alle Daten sind Live-Daten (kein Cache) die ggf. etwas Bearbeitungs-Zeit erfordern.</p>')
		self.wfile.write('<dl>\n')
		self.wfile.write('<dt><a href="/nodes.json">nodes.json</a></dt><dd>zur Verwendung mit ffmap (MACs anonymisiert)</dd>\n')
		self.wfile.write('<dt><a href="/node/ff00ff00ff00.json">/node/&lt;id&gt;.json</a></dt><dd><u>alle</u> vorhandenen Information zu der gewünschten Node</dd>\n')
		self.wfile.write('</dl>\n')
		self.wfile.write('</body></html>')
	
	def respond_node(self, nodeid):
		if nodeid == 'ff00ff00ff00':
			self.send_response(200)
			self.send_header('Content-Type', 'text/json')
			self.end_headers()
			self.wfile.write(json.dumps({
				'name': 'API-Example',
				'nodeid': nodeid,
				'META': 'Dies ist ein minimaler Beispiel-Datensatz. Herzlichen Glückwunsch, du hast das Prinzip der API kapiert.',
			}))
			return

		if not nodeid in self.storage.data:
			self.send_error(404, 'No node with id \'' + nodeid + '\' present.')
			return

		self.send_response(200)
		self.send_headers('Content-Type', 'text/json')
		self.end_headers()
		self.wfile.write(json.dumps(self.storage.data[nodeid]))

if __name__ == '__main__':
	server = HTTPServer(('localhost', 8888), BatcaveHttpRequestHandler)
	print("Server:", str(server))
	server.serve_forever()
